@@ -44,7 +44,7 @@ func polishSet() TranslationSet {
 		ViewLogs:           "pokaż logi",
 		RemoveImage:        "usuń obraz",
 		RemoveVolume:       "usuń wolumen",
-		RemoveNetwork:      "usuń seici",
+		RemoveNetwork:      "usuń sieci",
 		RemoveWithoutPrune: "usuń bez kasowania nieoznaczonych rodziców",
 		PruneContainers:    "wyczyść kontenery",
 		PruneVolumes:       "wyczyść nieużywane wolumeny",
@@ -61,7 +61,7 @@ func polishSet() TranslationSet {
 		StandaloneContainersTitle: "Kontenery samodzielne",
 		ImagesTitle:               "Obrazy",
 		VolumesTitle:              "Wolumeny",
-		NetworksTitle:             "Seici",
+		NetworksTitle:             "Sieci",
 		CustomCommandTitle:        "Własna komenda:",
 		ErrorTitle:                "Błąd",
 		LogsTitle:                 "Logi",
@@ -88,7 +88,7 @@ func polishSet() TranslationSet {
 		ConfirmPruneImages:          "Na pewno wyczyścić wszystkie nieużywane obrazy?",
 		ConfirmPruneContainers:      "Na pewno wyczyścić wszystkie nieuruchomione kontenery?",
 		ConfirmPruneVolumes:         "Na pewno wyczyścić wszystkie nieużywane wolumeny?",
-		ConfirmPruneNetworks:        "Na pewno wyczyścić wszystkie nieużywane seici?",
+		ConfirmPruneNetworks:        "Na pewno wyczyścić wszystkie nieużywane sieci?",
 		StopService:                 "Na pewno zatrzymać kontenery tego serwisu?",
 		StopContainer:               "Na pewno zatrzymać ten kontener?",
 		PressEnterToReturn:          "Wciśnij enter aby powrócić do lazydockera (ten komunikat może być wyłączony w konfiguracji poprzez ustawienie `gui.returnImmediately: true`)",
